<?php

/*
@copyright

Fleet Manager v6.5

Copyright (C) 2017-2023 Hyvikk Solutions <https://hyvikk.com/> All rights reserved.
Design and developed by Hyvikk Solutions <https://hyvikk.com/>

 */

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Model\Bookings;
use App\Model\DriverPayments;
use App\Model\ExpCats;
// use App\Model\PartsModel;
use App\Model\Expense;
use App\Model\FuelModel;
use App\Model\IncCats;
use App\Model\IncomeModel;
use App\Model\ServiceItemsModel;
use App\Model\User;
use App\Model\Vendor;
use App\Model\VehicleModel;
use App\Model\WorkOrders;
use App\Model\VehicleMovementModel;
use App\Model\DriverSalary;
use App\Model\DriverExpense;
use App\Model\FrozenModel;
use Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;
use Carbon\Carbon;

class ReportsController extends Controller {

	public function __construct() {
		// $this->middleware(['role:Admin']);
		$this->middleware('permission:Reports add', ['only' => ['create']]);
		$this->middleware('permission:Reports edit', ['only' => ['edit']]);
		$this->middleware('permission:Reports delete', ['only' => ['bulk_delete', 'destroy']]);
		$this->middleware('permission:Reports list');
	}

	public function expense() {
		$years = collect(DB::select("select distinct year(date) as years from expense where deleted_at is null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle['id'];
		}

		$data['vehicle_id'] = "";
		$data['year_select'] = date("Y");
		$data['month_select'] = date("n");
		$data['years'] = $y;

		$data['expense'] = Expense::whereIn('vehicle_id', $vehicle_ids)->whereYear("date", date("Y"))->whereMonth("date", date('m'))->get();
		return view('reports.expense', $data);
	}

	public function expense_post(Request $request) {

		$years = collect(DB::select("select distinct year(date) as years from expense where deleted_at is null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});
		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle['id'];
		}

		$data['vehicle_id'] = $request->vehicle_id;
		$data['year_select'] = $request->year;
		$data['month_select'] = $request->month;
		$data['years'] = $y;
		$data['show_print'] = 1;

		$records = Expense::whereIn('vehicle_id', $vehicle_ids)->whereYear("date", $request->year)->whereMonth("date", $request->month);
		if ($request->vehicle_id != null) {
			$data['expense'] = $records->where('vehicle_id', $request->vehicle_id)->get();
		} else {
			$data['expense'] = $records->get();
		}
		$where = vsprintf(str_replace('?', "'%s'", $records->toSql()), $records->getBindings());

		$frozen = FrozenModel::where('report_type', 'expense')->where('query_searched', $where)->orderBy('id','desc')->first();
		if (!empty($frozen)) {
			$data['show_print'] = 0;
			$records = Expense::whereIn('vehicle_id', $vehicle_ids)->whereYear("date", $request->year)->whereMonth("date", $request->month)->where('updated_at', '<=', $frozen->last_entry);
			if ($request->vehicle_id != null) {
				$data['expense'] = $records->where('vehicle_id', $request->vehicle_id)->get();
			} else {
				$data['expense'] = $records->get();
			}
		}
		return view('reports.expense', $data);	
		
	}

	public function expense_print(Request $request) {
		$data['vehicle_id'] = $request->vehicle_id;
		$data['year_select'] = $request->year;
		$data['month_select'] = $request->month;
		if (Auth::user()->group_id == null || Auth::user()->user_type == "S") {
			$data['vehicles'] = VehicleModel::get()->toArray();
		} else {

			$data['vehicles'] = VehicleModel::where('group_id', Auth::user()->group_id)->get()->toArray();
		}
		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle['id'];
		}
		$records = Expense::whereIn('vehicle_id', $vehicle_ids)->whereYear("date", $request->year)->whereMonth("date", $request->month);
		if ($request->vehicle_id != null) {
			$data['expense'] = $records->where('vehicle_id', $request->vehicle_id)->get();
		} else {
			$data['expense'] = $records->get();
		}
		$query = Expense::whereIn('vehicle_id', $vehicle_ids)->whereYear("date", $request->year)->whereMonth("date", $request->month);
		if ($request->vehicle_id != null) {
			$result = $query->where('vehicle_id', $request->vehicle_id)->orderBy('date', 'desc')->first();
		} else {
			 $result = $query->orderBy('date', 'desc')->first();
		}
		if (!empty($result)) {
			$where = vsprintf(str_replace('?', "'%s'", $records->toSql()), $records->getBindings());
			$frozen = new FrozenModel();
			$frozen->report_type = 'expense';
			$frozen->query_searched = $where;
			$frozen->last_entry = $result->updated_at;
			$frozen->save();
			return back()->withErrors(["error" => "Report Data Freezed!"]);
		} else {
			return back()->withErrors(["error" => "No data available to freeze!"]);
		}

		
	}

	public function income() {

		$years = collect(DB::select("select distinct year(date) as years from income where deleted_at is null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle['id'];
		}

		$data['vehicle_id'] = "";
		$data['year_select'] = date("Y");
		$data['month_select'] = date("n");
		$data['years'] = $y;

		$data['income'] = IncomeModel::whereIn('vehicle_id', $vehicle_ids)->whereYear("date", date("Y"))->whereMonth("date", date('m'))->get();
		return view('reports.income', $data);
	}

	public function income_post(Request $request) {
		$years = collect(DB::select("select distinct year(date) as years from income where deleted_at is null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle['id'];
		}

		$data['vehicle_id'] = $request->vehicle_id;
		$data['year_select'] = $request->year;
		$data['month_select'] = $request->month;
		$data['years'] = $y;

		$records = IncomeModel::whereYear("date", $request->year)->whereMonth("date", $request->month);
		if ($request->vehicle_id != null) {
			$data['income'] = $records->where('vehicle_id', $request->vehicle_id)->get();
		} else {
			$data['income'] = $records->whereIn('vehicle_id', $vehicle_ids)->get();
		}
		return view('reports.income', $data);
	}

	public function income_print(Request $request) {
		$data['vehicle_id'] = $request->vehicle_id;
		$data['year_select'] = $request->year;
		$data['month_select'] = $request->month;
		if (Auth::user()->group_id == null || Auth::user()->user_type == "S") {
			$data['vehicles'] = VehicleModel::get()->toArray();
		} else {
			$data['vehicles'] = VehicleModel::where('group_id', Auth::user()->group_id)->get()->toArray();
		}
		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle['id'];
		}

		$records = IncomeModel::whereYear("date", $request->year)->whereMonth("date", $request->month);
		if ($request->vehicle_id != null) {
			$data['income'] = $records->where('vehicle_id', $request->vehicle_id)->get();
		} else {
			$data['income'] = $records->whereIn('vehicle_id', $vehicle_ids)->get();
		}
		return view('reports.print_income', $data);
	}

	public function monthly() {

		$years = DB::select("select distinct year(date) as years from income  union select distinct year(date) as years from expense order by years desc");
		$y = array();
		$c = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {

			$y[date('Y')] = date('Y');

		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}

		$data['year_select'] = date("Y");
		$data['month_select'] = date("n");
		$data['vehicle_select'] = null;
		$data['years'] = $y;
		$data['income'] = IncomeModel::select(DB::raw("SUM(amount) as income"))->whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->whereIn('vehicle_id', $vehicle_ids)->get();
		$data['expenses'] = Expense::select(DB::raw("SUM(amount) as expense"))->whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->whereIn('vehicle_id', $vehicle_ids)->get();
		$data['expense_by_cat'] = Expense::select("type", "expense_type", DB::raw("sum(amount) as expense"))->whereYear('date', date('Y'))->whereMonth('date', date('n'))->groupBy(['expense_type', 'type'])->whereIn('vehicle_id', $vehicle_ids)->get();

		$data['income_by_cat'] = IncomeModel::select("income_cat", DB::raw("sum(amount) as amount"))->whereYear('date', date('Y'))->whereMonth('date', date('n'))->groupBy(['income_cat'])->whereIn('vehicle_id', $vehicle_ids)->get();

		$ss = ServiceItemsModel::get();
		foreach ($ss as $s) {
			$c[$s->id] = $s->description;
		}

		$kk = ExpCats::get();

		foreach ($kk as $k) {
			$b[$k->id] = $k->name;

		}
		$hh = IncCats::get();

		foreach ($hh as $k) {
			$i[$k->id] = $k->name;

		}
		$data['service'] = $c;
		$data['expense_cats'] = $b;
		$data['income_cats'] = $i;
		$data['result'] = "";


		return view("reports.monthly", $data);
	}

	public function delinquent() {
		$years = collect(DB::select("select distinct year(date) as years from income where deleted_at is null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});


		$data['vehicle_id'] = "";
		$data['year_select'] = date("Y");
		$data['month_select'] = date("n");
		$data['years'] = $y;

		return view("reports.delinquent", $data);
	}

	public function booking() {
		$years = collect(DB::select("select distinct year(pickup) as years from bookings where deleted_at is null and pickup is not null order by years desc"));

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}
		$data['vehicle_select'] = "";
		$data['customer_select'] = "";
		$data['customers'] = User::where('user_type', 'C')->get();
		$data['years'] = $y;
		$data['year_select'] = date("Y");
		$data['month_select'] = date("n");
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$data['bookings'] = Bookings::whereYear("pickup", date("Y"))->whereMonth("pickup", date("n"))->whereIn('vehicle_id', $vehicle_ids)->get();

		return view("reports.booking", $data);
	}

	public function booking_post(Request $request) {
		$years = collect(DB::select("select distinct year(pickup) as years from bookings where deleted_at is null and pickup is not null order by years desc"));

		$y = array();
		$data['customers'] = User::where('user_type', 'C')->get();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}
		$data['vehicle_select'] = $request->get('vehicle_id');
		$data['customer_select'] = $request->get('customer_id');
		$data['years'] = $y;
		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$data['bookings'] = Bookings::whereYear("pickup", $data['year_select'])->whereMonth("pickup", $data['month_select'])->whereIn('vehicle_id', $vehicle_ids);
		if ($request->get("vehicle_id") != "") {
			$data['bookings'] = $data['bookings']->where("vehicle_id", $request->get("vehicle_id"));
		}
		if ($request->get("customer_id") != "") {
			$data['bookings'] = $data['bookings']->where("customer_id", $request->get("customer_id"));
		}
		$data['bookings'] = $data['bookings']->get();

		return view("reports.booking", $data);
	}
	public function delinquent_post(Request $request) {

		$years = DB::select("select distinct year(date) as years from income where deleted_at is null order by years desc");
		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}
		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");
		foreach ($data['vehicles'] as $row) {
			$data['v'][$row['id']] = $row;
		}

		$data['vehicle_id'] = $request->get("vehicle_id");

		$income = IncomeModel::select(['vehicle_id', 'income_cat', 'date', DB::raw('sum(amount) as Income2,dayname(date) as day')])->whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->groupBy('date')->orderBy('date');
		if ($data['vehicle_id'] != "") {
			$data['data'] = $income->where('vehicle_id', $data['vehicle_id'])->get();
		} else {
			$data['data'] = $income->whereIn('vehicle_id', $vehicle_ids)->get();
		}

		$data['years'] = $y;
		$data['result'] = "";

		return view("reports.delinquent", $data);
	}

	/*
	    public function parts() {
	    $data['parts'] = PartsModel::get();

	    return view("reports.parts", $data);
	    }
	    public function parts_post(Request $request) {
	    $data['parts'] = PartsModel::get();
	    $data['parts2'] = TransactionModel::wherePart_id($request->get("part"))->get();

	    $data['result'] = "";
	    return view("reports.parts", $data);
	    }
*/

	public function monthly_post(Request $request) {

		$years = DB::select("select distinct year(date) as years from income  union select distinct year(date) as years from expense order by years desc");
		$y = array();
		$b = array();
		$i = array();
		$c = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}
		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");
		$data['vehicle_select'] = $request->get("vehicle_id");
		

		$records = Expense::whereIn('vehicle_id', $vehicle_ids)->whereYear("date", $request->year)->whereMonth("date", $request->month);
		if ($request->vehicle_id != null) {
			$data['expense'] = $records->where('vehicle_id', $request->vehicle_id)->get();
		} else {
			$data['expense'] = $records->get();
		}
		$where = vsprintf(str_replace('?', "'%s'", $records->toSql()), $records->getBindings());

		$frozen = FrozenModel::where('report_type', 'monthly_expense')->where('query_searched', $where)->orderBy('id','desc')->first();
		if (!empty($frozen)) {
			$data['show_freezed'] = 1;
			$expense1 = Expense::select(DB::raw("SUM(amount) as expense"))->whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->where('updated_at', '<=', $frozen->last_entry)->whereIn('vehicle_id', $vehicle_ids);
			$expense2 = Expense::select("type", "expense_type", DB::raw("sum(amount) as expense"))->whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->where('updated_at', '<=', $frozen->last_entry)->whereIn('vehicle_id', $vehicle_ids)->groupBy(['expense_type', 'type']);
		} else {	
		$data['show_print'] = 1;	
			$expense1 = Expense::select(DB::raw("SUM(amount) as expense"))->whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->whereIn('vehicle_id', $vehicle_ids);
			$expense2 = Expense::select("type", "expense_type", DB::raw("sum(amount) as expense"))->whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->whereIn('vehicle_id', $vehicle_ids)->groupBy(['expense_type', 'type']);
		}
		
		if ($data['vehicle_select'] != "") {
			$data['expenses'] = $expense1->where('vehicle_id', $data['vehicle_select'])->get();
			$data['expense_by_cat'] = $expense2->where('vehicle_id', $data['vehicle_select'])->get();
		} else {
			$data['expenses'] = $expense1->get();
			$data['expense_by_cat'] = $expense2->get();
		}

		$ss = ServiceItemsModel::get();
		foreach ($ss as $s) {
			$c[$s->id] = $s->description;
		}

		$kk = ExpCats::get();

		foreach ($kk as $k) {
			$b[$k->id] = $k->name;

		}
		
		$data['service'] = $c;
		$data['expense_cats'] = $b;

		$data['years'] = $y;
		$data['result'] = "";
		
		return view("reports.monthly", $data);
	}

	public function fuel() {
		$years = collect(DB::select("select distinct year(date) as years from fuel where deleted_at is null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle['id'];
		}
		$data['fuel'] = FuelModel::whereIn('vehicle_id', $vehicle_ids)->get();
		$data['vehicle_id'] = "";
		$data['year_select'] = date("Y");
		$data['month_select'] = date("n");
		$data['years'] = $y;
		return view('reports.fuel', $data);
	}

	public function fuel_post(Request $request) {

		$years = collect(DB::select("select distinct year(date) as years from income where deleted_at is null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});


		$data['vehicle_id'] = $request->get('vehicle_id');
		$data['year_select'] = $request->get('year');
		$data['month_select'] = $request->get('month');
		$data['years'] = $y;
		$data['show_print'] = 1;
		$v = " and vehicle_id=" . $data['vehicle_id'];
		if ($request->get('month') == '0') {
			$fueQuery = FuelModel::whereYear('date', $data['year_select'])->where('vehicle_id', $request->get('vehicle_id'));
			$data['fuel'] = $fueQuery->get();

		} else {
			$fueQuery = FuelModel::whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->where('vehicle_id', $request->get('vehicle_id'));
			$data['fuel'] = $fueQuery->get();
		}
		$where = vsprintf(str_replace('?', "'%s'", $fueQuery->toSql()), $fueQuery->getBindings());
		$frozen = FrozenModel::where('report_type', 'fuel')->where('query_searched', $where)->orderBy('id','desc')->first();

		if (!empty($frozen)) {
			$data['show_print'] = 0;
			if ($request->get('month') == '0') {
				$fueQuery = FuelModel::whereYear('date', $data['year_select'])->where('vehicle_id', $request->get('vehicle_id'))->where('updated_at', '<=', $frozen->last_entry);
				$data['fuel'] = $fueQuery->get();
			} else {
				$fueQuery = FuelModel::whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->where('vehicle_id', $request->get('vehicle_id'))->where('updated_at', '<=', $frozen->last_entry);
				$data['fuel'] = $fueQuery->get();
			} 
		} else {
			if ($request->get('month') == '0') {
				$fueQuery = FuelModel::whereYear('date', $data['year_select'])->where('vehicle_id', $request->get('vehicle_id'));
				$data['fuel'] = $fueQuery->get();
			} else {
				$fueQuery = FuelModel::whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->where('vehicle_id', $request->get('vehicle_id'));
				$data['fuel'] = $fueQuery->get();
			}
		}

		$data['result'] = "";
		return view('reports.fuel', $data);
	}

	public function print_fuel(Request $request) {

		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});


		$data['vehicle_id'] = $request->get('vehicle_id');
		$data['year_select'] = $request->get('year');
		$data['month_select'] = $request->get('month');
		$data['show_print'] = 1;

		if ($request->get('month') == '0') {
			$fueQuery = FuelModel::whereYear('date', $data['year_select'])->where('vehicle_id', $request->get('vehicle_id'));
			$result1 = $fueQuery->get();

		} else {
			$fueQuery = FuelModel::whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->where('vehicle_id', $request->get('vehicle_id'));
			$result1 = $fueQuery->get();
		}


		if ($request->get('month') == '0') {
			$query = FuelModel::whereYear('date', $data['year_select'])->where('vehicle_id', $request->get('vehicle_id'));
			$result2 = $query->orderBy('date', 'desc')->first();

		} else {
			$query = FuelModel::whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->where('vehicle_id', $request->get('vehicle_id'));
			$result2 = $query->orderBy('date', 'desc')->first();
		}

		if (!empty($result2)) {
			$where = vsprintf(str_replace('?', "'%s'", $fueQuery->toSql()), $fueQuery->getBindings());
			$frozen = new FrozenModel();
			$frozen->report_type = 'fuel';
			$frozen->query_searched = $where;
			$frozen->last_entry = $result2->updated_at;
			$frozen->save();
			return back()->withErrors(["error" => "Report Data Freezed!"]);
		} else {
			return back()->withErrors(["error" => "No data available to freeze!"]);
		}
		
	}

	public function yearly() {
		$years = DB::select("select distinct year(date) as years from income  union select distinct year(date) as years from expense order by years desc");
		$y = array();
		$c = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {

			$y[date('Y')] = date('Y');

		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}

		$data['year_select'] = date("Y");

		$data['vehicle_select'] = null;
		$data['years'] = $y;
		
		$data['expenses'] = Expense::select(DB::raw('sum(amount) as expense'))->whereYear('date', date("Y"))->whereIn('vehicle_id', $vehicle_ids)->get();
		$data['expense_by_cat'] = Expense::select(['type', 'expense_type', DB::raw('sum(amount) as expense')])->whereYear('date', date('Y'))->whereIn('vehicle_id', $vehicle_ids)->groupBy(['expense_type', 'type'])->get();
		

		$ss = ServiceItemsModel::get();
		foreach ($ss as $s) {
			$c[$s->id] = $s->description;
		}

		$kk = ExpCats::get();

		foreach ($kk as $k) {
			$b[$k->id] = $k->name;

		}
		

		$data['service'] = $c;
		$data['expense_cats'] = $b;
		$data['result'] = "";
		return view('reports.yearly', $data);
	}

	public function yearly_post(Request $request) {

		$years = DB::select("select distinct year(date) as years from income  union select distinct year(date) as years from expense order by years desc");
		$y = array();
		$b = array();
		$i = array();
		$c = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}
		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$data['year_select'] = $request->get("year");
		$data['vehicle_select'] = $request->get("vehicle_id");

		
		$expense1 = Expense::select(DB::raw("sum(amount) as expense"))->whereYear('date', $data['year_select']);
		$expense2 = Expense::select("type", "expense_type", DB::raw("sum(amount) as expense"))->whereYear('date', $data['year_select'])->groupBy('expense_type', 'type');
		
		if ($data['vehicle_select'] != "") {
			$data['expenses'] = $expense1->where('vehicle_id', $data['vehicle_select'])->get();
			$data['expense_by_cat'] = $expense2->where('vehicle_id', $data['vehicle_select'])->get();
		} else {
			$data['expenses'] = $expense1->whereIn('vehicle_id', $vehicle_ids)->get();
			$data['expense_by_cat'] = $expense2->whereIn('vehicle_id', $vehicle_ids)->get();
		}

		$ss = ServiceItemsModel::get();
		foreach ($ss as $s) {
			$c[$s->id] = $s->description;
		}

		$kk = ExpCats::get();

		foreach ($kk as $k) {
			$b[$k->id] = $k->name;

		}
		

		$data['service'] = $c;
		$data['expense_cats'] = $b;

		$data['years'] = $y;
		$data['result'] = "";
		return view('reports.yearly', $data);
	}


	public function print_yearly(Request $request) {

		$b = array();
		$i = array();
		$c = array();

		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}

		$data['year_select'] = $request->get("year");
		$data['vehicle_select'] = $request->get("vehicle_id");

		$income1 = IncomeModel::select(DB::raw("sum(amount) as income"))->whereYear('date', $data['year_select']);
		$expense1 = Expense::select(DB::raw("sum(amount) as expense"))->whereYear('date', $data['year_select']);
		$expense2 = Expense::select("type", "expense_type", DB::raw("sum(amount) as expense"))->whereYear('date', $data['year_select'])->groupBy('expense_type', 'type');
		$income2 = IncomeModel::select('income_cat', DB::raw("sum(amount) as amount"))->whereYear('date', $data['year_select'])->groupBy('income_cat');
		if ($data['vehicle_select'] != "") {
			$data['income'] = $income1->where('vehicle_id', $data['vehicle_select'])->get();
			$data['expenses'] = $expense1->where('vehicle_id', $data['vehicle_select'])->get();
			$data['expense_by_cat'] = $expense2->where('vehicle_id', $data['vehicle_select'])->get();
			$data['income_by_cat'] = $income2->where('vehicle_id', $data['vehicle_select'])->get();
		} else {
			$data['income'] = $income1->whereIn('vehicle_id', $vehicle_ids)->get();
			$data['expenses'] = $expense1->whereIn('vehicle_id', $vehicle_ids)->get();
			$data['expense_by_cat'] = $expense2->whereIn('vehicle_id', $vehicle_ids)->get();
			$data['income_by_cat'] = $income2->whereIn('vehicle_id', $vehicle_ids)->get();
		}

		$ss = ServiceItemsModel::get();
		foreach ($ss as $s) {
			$c[$s->id] = $s->description;
		}

		$kk = ExpCats::get();

		foreach ($kk as $k) {
			$b[$k->id] = $k->name;

		}
		$hh = IncCats::get();

		foreach ($hh as $k) {
			$i[$k->id] = $k->name;

		}

		$data['service'] = $c;
		$data['expense_cats'] = $b;
		$data['income_cats'] = $i;

		$data['vehicle'] = VehicleModel::find($request->get('vehicle_id'));

		return view('reports.print_yearly', $data);
	}

	public function customReport() {


		$data['select_from'] = Carbon::now()->startOfMonth()->format('Y-m-d');
		$data['select_to'] = Carbon::now()->endOfMonth()->format('Y-m-d');
		$data['select_vehicle'] = '';
		$data['vehicles'] = VehicleModel::get();
		$data['vehicle'] = [];

		return view('reports.custom', $data); 
	}

	public function customReportPost(Request $request) {
		$this->validate($request, [
			'from_date' => 'required',
			'to_date' => 'required',
			//'start_odm' => 'required',
			//'end_odm' => 'required',
			'vehicle_id' => 'required',
		]);
		$data['show_print'] = 1;
		$data['select_from'] = $request->from_date;
		$data['select_to'] = $request->to_date;
		$data['select_vehicle'] = $request->vehicle_id;

		$data['from_date'] = $request->from_date;
		$from_date = $request->from_date.' 00:00:00';
		$to_date = $request->to_date.' 23:59:59';
		$data['to_date'] = $request->to_date;
		//$data['end_odm'] = $request->end_odm;
		//$data['start_odm'] = $request->start_odm;
		$data['vehicles'] = VehicleModel::get();
		$movements = DB::table('vehicle_movements')
		->where('vehicle_id', $request->vehicle_id)
    	->whereRaw('loading BETWEEN ? AND ?', [$request->from_date, $request->to_date])
    	->orderBy('loading', 'ASC')
    	->get();
   	  

    	$fillingsQuery = DB::table('fuel')
		->where('vehicle_id', $request->vehicle_id)
    	->whereRaw('date BETWEEN ? AND ?', [$request->from_date, $request->to_date]);
    	$fillingsQueryResult = $fillingsQuery->orderBy('updated_at','desc')->first();

    	$where1 = vsprintf(str_replace('?', "'%s'", $fillingsQuery->toSql()), $fillingsQuery->getBindings()); 
    	$frozen1 = FrozenModel::where('report_type', 'custom_report_fuel')->where('query_searched', $where1)->orderBy('id','desc')->first();
    	if (!empty($frozen1)) {
    		$data['show_print'] = 0;
    		$fillings = DB::table('fuel')
			->where('vehicle_id', $request->vehicle_id)
			->where('updated_at', '<=', $frozen1->last_entry)
	    	->whereRaw('date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
	    	->orderBy('date', 'ASC')
	    	->get();

    	} else {
    		$fillings = DB::table('fuel')
			->where('vehicle_id', $request->vehicle_id)
	    	->whereRaw('date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
	    	->orderBy('date', 'ASC')
	    	->get();
    	}



    	$vendors = Vendor::get()->toArray();
    	$vendorData  = array_column($vendors, 'name', 'id');


		$vehicle = VehicleModel::where('id', $request->vehicle_id)->first();
		if (empty($vehicle->driver)) {
			return back()->withErrors(["error" => "Selected Vehicle is not assigned any driver."]);
		}		
		$driver =  User::where('user_type', 'D')->where('id', $vehicle->driver->driver_id)->first();
		if(empty($driver)) {
			return back()->with('msg', trans('Driver not assigner to the selected vehicle'));
		}

		

    	$driverPaysQuery = DB::table('driver_payments')
		->where('driver_id', $vehicle->driver->driver_id)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date]);
    	$driverPaysQueryResult = $driverPaysQuery->orderBy('updated_at','desc')->first();

    	$where2 = vsprintf(str_replace('?', "'%s'", $driverPaysQuery->toSql()), $driverPaysQuery->getBindings());
    	$frozen2 = FrozenModel::where('report_type', 'custom_report_driver_payment')->where('query_searched', $where2)->orderBy('id','desc')->first();
    	if (!empty($frozen2)) {
    		$driverPays = DB::table('driver_payments')
			->where('driver_id', $vehicle->driver->driver_id)
			->where('updated_at', '<=', $frozen2->last_entry)
	    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
	    	->orderBy('amount_date', 'ASC')
	    	->get();

    	} else {
    		$driverPays = DB::table('driver_payments')
			->where('driver_id', $vehicle->driver->driver_id)
	    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
	    	->orderBy('amount_date', 'ASC')
	    	->get();
    	}

    	$driverExpenses = DB::table('driver_expense')
		->where('driver_id', $vehicle->driver->driver_id)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
    	->orderBy('amount_date', 'ASC')
    	->get();

    	

    	$driverExpensesQuery = DB::table('driver_expense')
		->where('driver_id', $vehicle->driver->driver_id)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date]);
    	$driverExpensesQueryResult = $driverExpensesQuery->orderBy('updated_at','desc')->first();

    	$where3 = vsprintf(str_replace('?', "'%s'", $driverExpensesQuery->toSql()), $driverExpensesQuery->getBindings()); 
    	$frozen3 = FrozenModel::where('report_type', 'custom_report_driver_expense')->where('query_searched', $where3)->orderBy('id','desc')->first();
    	if (!empty($frozen3)) {
    		$driverExpenses = DB::table('driver_expense')
			->where('driver_id', $vehicle->driver->driver_id)
			->where('updated_at', '<=', $frozen3->last_entry)
	    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
	    	->orderBy('amount_date', 'ASC')
	    	->get();
    	} else {
    		$driverExpenses = DB::table('driver_expense')
			->where('driver_id', $vehicle->driver->driver_id)
	    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
	    	->orderBy('amount_date', 'ASC')
	    	->get();
    	}

    	$month = Carbon::parse($from_date)->format('m-Y');

    	  

    	$driversalariesQuery = DB::table('driver_salary')
		->where('driver_id', $vehicle->driver->driver_id)
    	->where('salary_month', $month);
    	$driversalariesQueryResult = $driversalariesQuery->orderBy('updated_at','desc')->first();

    	$where4 = vsprintf(str_replace('?', "'%s'", $driversalariesQuery->toSql()), $driversalariesQuery->getBindings()); 

    	$frozen4 = FrozenModel::where('report_type', 'custom_report_driver_salary')->where('query_searched', $where4)->orderBy('id','desc')->first();

    	if (!empty($frozen4)) {
    		$salaries = DB::table('driver_salary')
			->where('driver_id', $vehicle->driver->driver_id)
			->where('updated_at', $frozen4->last_entry)
			->where('salary_month', $month)
	    	->orderBy('created_at', 'ASC')
	    	->get();

    	} else {
    		$salaries = DB::table('driver_salary')
			->where('driver_id', $vehicle->driver->driver_id)
			->where('salary_month', $month)
	    	->orderBy('created_at', 'ASC')
	    	->get();
    	}   	

    	$expensesQuery = DB::table('expense')
		->where('vehicle_id', $request->vehicle_id)
    	->whereRaw('date BETWEEN ? AND ?', [$request->from_date, $request->to_date]);
    	$expensesQueryResult = $expensesQuery->orderBy('updated_at','desc')->first();

    	$where5 = vsprintf(str_replace('?', "'%s'", $expensesQuery->toSql()), $expensesQuery->getBindings()); 
    	$frozen5 = FrozenModel::where('report_type', 'custom_report_expense')->where('query_searched', $where5)->orderBy('id','desc')->first();
    	if (!empty($frozen5)) {
    		$expenses = DB::table('expense')
			->where('vehicle_id', $request->vehicle_id)
			->where('updated_at', $frozen5->last_entry)
	    	->whereRaw('date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
	    	->orderBy('date', 'ASC')
	    	->get();

    	} else {
    		$expenses = DB::table('expense')
			->where('vehicle_id', $request->vehicle_id)
	    	->whereRaw('date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
	    	->orderBy('date', 'ASC')
	    	->get();
    	}

		$data['vehicle'] = $vehicle;
		$data['driver'] = $driver ?? [];
		$data['movements'] = $movements ?? [];
		$data['fillings'] = $fillings ?? [];
		$data['vendorData'] = $vendorData ?? [];
		$data['driverPays'] = $driverPays ?? [];
		$data['expenses'] = $expenses ?? [];
		$data['salaries'] = $salaries ?? [];
		$data['driverExpenses'] = $driverExpenses ?? [];
		
		
		return view('reports.custom', $data); 
		
	}

	public function customReportFreeze(Request $request)
	{
		$this->validate($request, [
			'from_date' => 'required',
			'to_date' => 'required',
			//'start_odm' => 'required',
			//'end_odm' => 'required',
			'vehicle_id' => 'required',
		]);

		$from_date = $request->from_date.' 00:00:00';
		$to_date = $request->to_date.' 23:59:59';
		$data['to_date'] = $request->to_date;
		$data['vehicles'] = VehicleModel::get();

		$movements = DB::table('vehicle_movements')
		->where('vehicle_id', $request->vehicle_id)
    	->whereRaw('loading BETWEEN ? AND ?', [$request->from_date, $request->to_date])
    	->orderBy('loading', 'ASC')
    	->get();

    	$fillings = DB::table('fuel')
		->where('vehicle_id', $request->vehicle_id)
    	->whereRaw('date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
    	->orderBy('date', 'ASC')
    	->get(); 

    	$fillingsQuery = DB::table('fuel')
		->where('vehicle_id', $request->vehicle_id)
    	->whereRaw('date BETWEEN ? AND ?', [$request->from_date, $request->to_date]);
    	$fillingsQueryResult = $fillingsQuery->orderBy('updated_at','desc')->first();

    	$where1 = vsprintf(str_replace('?', "'%s'", $fillingsQuery->toSql()), $fillingsQuery->getBindings());    	
		if (!empty($fillingsQueryResult)) {
			$fillingUpdated = $fillingsQueryResult->updated_at;			
		} else {
			$fillingUpdated = Carbon::now()->subDays(100);
		}

		$frozen1 = new FrozenModel();
		$frozen1->report_type = 'custom_report_fuel';
		$frozen1->query_searched = $where1;
		$frozen1->last_entry = $fillingUpdated;
		$frozen1->save();   	  	

    	$vendors = Vendor::get()->toArray();
    	$vendorData  = array_column($vendors, 'name', 'id');


		$vehicle = VehicleModel::where('id', $request->vehicle_id)->first();
		if (empty($vehicle->driver)) {
			return back()->withErrors(["error" => "Selected Vehicle is not assigned any driver."]);
		}		
		$driver =  User::where('user_type', 'D')->where('id', $vehicle->driver->driver_id)->first();
		if(empty($driver)) {
			return back()->with('msg', trans('Driver not assigner to the selected vehicle'));
		}

		$driverPays = DB::table('driver_payments')
		->where('driver_id', $vehicle->driver->driver_id)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
    	->orderBy('amount_date', 'ASC')
    	->get();

    	$driverPaysQuery = DB::table('driver_payments')
		->where('driver_id', $vehicle->driver->driver_id)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date]);
    	$driverPaysQueryResult = $driverPaysQuery->orderBy('updated_at','desc')->first();

    	$where2 = vsprintf(str_replace('?', "'%s'", $driverPaysQuery->toSql()), $driverPaysQuery->getBindings());    	
		if (!empty($driverPaysQueryResult)) {
			$paymentUpdated = $driverPaysQueryResult->updated_at;			
		} else {
			$paymentUpdated = Carbon::now()->subDays(100);
		}

		$frozen2 = new FrozenModel();
		$frozen2->report_type = 'custom_report_driver_payment';
		$frozen2->query_searched = $where2;
		$frozen2->last_entry = $paymentUpdated;
		$frozen2->save();

    	$driverExpenses = DB::table('driver_expense')
		->where('driver_id', $vehicle->driver->driver_id)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
    	->orderBy('amount_date', 'ASC')
    	->get();

    	$driverExpensesQuery = DB::table('driver_expense')
		->where('driver_id', $vehicle->driver->driver_id)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$request->from_date, $request->to_date]);
    	$driverExpensesQueryResult = $driverExpensesQuery->orderBy('updated_at','desc')->first();

    	$where1 = vsprintf(str_replace('?', "'%s'", $driverExpensesQuery->toSql()), $driverExpensesQuery->getBindings());    	
		if (!empty($driverExpensesQueryResult)) {
			$expenseUpdated = $driverExpensesQueryResult->updated_at;			
		} else {
			$expenseUpdated = Carbon::now()->subDays(100);
		}

		$frozen3 = new FrozenModel();
		$frozen3->report_type = 'custom_report_driver_expense';
		$frozen3->query_searched = $where1;
		$frozen3->last_entry = $expenseUpdated;
		$frozen3->save();

		$month = Carbon::parse($from_date)->format('m-Y');

    	$salaries = DB::table('driver_salary')
		->where('driver_id', $vehicle->driver->driver_id)
		->where('salary_month', $month)
    	->orderBy('created_at', 'ASC')
    	->get();  

    	$driversalariesQuery = DB::table('driver_salary')
		->where('driver_id', $vehicle->driver->driver_id)
    	->where('salary_month', $month);
    	$driversalariesQueryResult = $driversalariesQuery->orderBy('updated_at','desc')->first();

    	$where1 = vsprintf(str_replace('?', "'%s'", $driversalariesQuery->toSql()), $driversalariesQuery->getBindings());    	
		if (!empty($driversalariesQueryResult)) {
			$salaryUpdated = $driversalariesQueryResult->updated_at;			
		} else {
			$salaryUpdated = Carbon::now()->subDays(100);
		}

		$frozen4 = new FrozenModel();
		$frozen4->report_type = 'custom_report_driver_salary';
		$frozen4->query_searched = $where1;
		$frozen4->last_entry = $salaryUpdated;
		$frozen4->save();

    	$expenses = DB::table('expense')
		->where('vehicle_id', $request->vehicle_id)
    	->whereRaw('date BETWEEN ? AND ?', [$request->from_date, $request->to_date])
    	->orderBy('date', 'ASC')
    	->get();


    	$expensesQuery = DB::table('expense')
		->where('vehicle_id', $request->vehicle_id)
    	->whereRaw('date BETWEEN ? AND ?', [$request->from_date, $request->to_date]);
    	$expensesQueryResult = $expensesQuery->orderBy('updated_at','desc')->first();

    	$where5 = vsprintf(str_replace('?', "'%s'", $expensesQuery->toSql()), $expensesQuery->getBindings());    	
		if (!empty($expensesQueryResult)) {
			$expUpdated = $expensesQueryResult->updated_at;			
		} else {
			$expUpdated = Carbon::now()->subDays(100);
		}

		$frozen5 = new FrozenModel();
		$frozen5->report_type = 'custom_report_expense';
		$frozen5->query_searched = $where5;
		$frozen5->last_entry = $expUpdated;
		$frozen5->save();
		return back()->withErrors(["error" => "Report Data Freezed!"]);
	}

	

	public function vendors() {

		// $data['details'] = DB::select("select vendor_id,sum(price) as total from work_orders where deleted_at is null group by vendor_id"));
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$data['details'] = WorkOrders::select(['vendor_id', DB::raw('sum(price) as total')])->whereIn('vehicle_id', $vehicle_ids)->groupBy('vendor_id')->get();
		// dd($data);

		$kk = WorkOrders::select('vendor_id')->whereIn('vehicle_id', $vehicle_ids)->groupBy('vendor_id')->get();
		$b = array();
		foreach ($kk as $k) {
			$b[$k->vendor_id] = $k->vendor->name;

		}
		$data['vendors'] = $b;
		$data['date1'] = null;
		$data['date2'] = null;
		return view('reports.vendor', $data);
	}

	public function vendors_post(Request $request) {

		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$start = date('Y-m-d H:i:s', strtotime($request->get('date1')));

		$end = date('Y-m-d H:i:s', strtotime($request->get('date2')));
		$data['details'] = WorkOrders::select(['vendor_id', DB::raw('sum(price) as total')])->whereBetween('created_at', [$start, $end])->whereIn('vehicle_id', $vehicle_ids)->groupBy('vendor_id')->get();

		$kk = WorkOrders::select('vendor_id')->whereIn('vehicle_id', $vehicle_ids)->groupBy('vendor_id')->get();
		$b = array();
		foreach ($kk as $k) {
			$b[$k->vendor_id] = $k->vendor->name;

		}
		$data['vendors'] = $b;
		$data['date1'] = $request->date1;
		$data['date2'] = $request->date2;
		return view('reports.vendor', $data);

	}

	public function drivers() {
		$data['year_select'] = date('Y');
		$data['month_select'] = date('F');
		$data['driver_select'] = '';

		$data['drivers'] = User::where('user_type', 'D')->get();
		return view('reports.driver', $data);

	}

	public function drivers_post(Request $request) {
		
		$this->validate($request, [
			'month' => 'required',
			'year' => 'required',
			'driver' => 'required',
		]);
		$data['show_print'] = 1;
		$data['year_select'] = $request->year;
		$data['month_select'] = $request->month;
		$data['driver_select'] = $request->driver;
		
		$data['drivers'] = User::where('user_type', 'D')->get();

		$monthNumber = Carbon::parse($request->month)->format('m');
		$salaryMonthYear = $monthNumber.'-'.$request->year;
		$firstDate = Carbon::createFromDate($request->year, $monthNumber, 1)->startOfDay()->format('Y-m-d');
	    $lastDate = Carbon::createFromDate($request->year, $monthNumber, 1)->endOfMonth()->format('Y-m-d');

	    $driverExpensesQuery = DB::table('driver_expense')
		->where('driver_id', $request->driver)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$firstDate, $lastDate]);
    	$driverExpensesQueryResult = $driverExpensesQuery->orderBy('updated_at','desc')->first();
    	$where1 = vsprintf(str_replace('?', "'%s'", $driverExpensesQuery->toSql()), $driverExpensesQuery->getBindings());  

    	$frozen1 = FrozenModel::where('report_type', 'driver_expense')->where('query_searched', $where1)->orderBy('id','desc')->first();
    	if (!empty($frozen1)) {
    		$data['show_print'] = 0;
    		$driverExpenses = DB::table('driver_expense')
			->where('driver_id', $request->driver)
			->where('updated_at', '<=', $frozen1->last_entry)
	    	->whereRaw('amount_date BETWEEN ? AND ?', [$firstDate, $lastDate])
	    	->sum('amount');
    	} else {
    		$driverExpenses = DB::table('driver_expense')
			->where('driver_id', $request->driver)
	    	->whereRaw('amount_date BETWEEN ? AND ?', [$firstDate, $lastDate])
	    	->sum('amount');
    	}
    	$driverPaysQuery = DB::table('driver_payments')
		->where('driver_id', $request->driver)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$firstDate, $lastDate]);
    	$driverPaysQueryResult = $driverPaysQuery->orderBy('updated_at','desc')->first();

    	$where2 = vsprintf(str_replace('?', "'%s'", $driverPaysQuery->toSql()), $driverPaysQuery->getBindings());
		$frozen2 = FrozenModel::where('report_type', 'driver_payment')->where('query_searched', $where2)->orderBy('id','desc')->first();
		if (!empty($frozen2)) {
			$driverPays = DB::table('driver_payments')
			->where('driver_id', $request->driver)
			->where('updated_at', '<=', $frozen2->last_entry)
	    	->whereRaw('amount_date BETWEEN ? AND ?', [$firstDate, $lastDate])
	    	->sum('amount');
		} else {
			$driverPays = DB::table('driver_payments')
			->where('driver_id', $request->driver)
	    	->whereRaw('amount_date BETWEEN ? AND ?', [$firstDate, $lastDate])
	    	->sum('amount');
		}
		$driverQuery =  DriverSalary::where('salary_month', $salaryMonthYear)->where('driver_id', $request->driver);
		$salaryResult = $driverQuery->orderBy('updated_at','desc')->first();
		$where3  = vsprintf(str_replace('?', "'%s'", $driverQuery->toSql()), $driverQuery->getBindings());
		$frozen3 = FrozenModel::where('report_type', 'driver_salary')->where('query_searched', $where3)->orderBy('id','desc')->first();
		if (!empty($frozen3)) {
			$driver_salaries = DriverSalary::where('salary_month', $salaryMonthYear)->where('driver_id', $request->driver)->where('updated_at', '<=', $frozen3->last_entry)->sum('amount');
		} else {
			$driver_salaries = DriverSalary::where('salary_month', $salaryMonthYear)->where('driver_id', $request->driver)->sum('amount');
		}	

		

		$data['driverExpenses'] = $driverExpenses ?? 0;
		$data['driverPays'] = $driverPays ?? 0;
		$data['driver_salaries'] = $driver_salaries ?? 0;
		$data['total'] = $data['driver_salaries'] + $data['driverPays'] + $data['driverExpenses'];


		return view('reports.driver', $data);

	}

	public function print_driver(Request $request) {

		
		$this->validate($request, [
			'month' => 'required',
			'year' => 'required',
			'driver' => 'required',
		]);
		$data['show_print'] = 1;

		$monthNumber = Carbon::parse($request->month)->format('m');
		$salaryMonthYear = $monthNumber.'-'.$request->year;
		$firstDate = Carbon::createFromDate($request->year, $monthNumber, 1)->startOfDay()->format('Y-m-d');
	    $lastDate = Carbon::createFromDate($request->year, $monthNumber, 1)->endOfMonth()->format('Y-m-d');

		$driverExpenses = DB::table('driver_expense')
		->where('driver_id', $request->driver)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$firstDate, $lastDate])
    	->sum('amount');

    	$driverExpensesQuery = DB::table('driver_expense')
		->where('driver_id', $request->driver)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$firstDate, $lastDate]);
    	$driverExpensesQueryResult = $driverExpensesQuery->orderBy('updated_at','desc')->first();

    	$where1 = vsprintf(str_replace('?', "'%s'", $driverExpensesQuery->toSql()), $driverExpensesQuery->getBindings());    	
		if (!empty($driverExpensesQueryResult)) {
			$expenseUpdated = $driverExpensesQueryResult->updated_at;			
		} else {
			$expenseUpdated = Carbon::now()->subDays(100);
		}

		$frozen1 = new FrozenModel();
		$frozen1->report_type = 'driver_expense';
		$frozen1->query_searched = $where1;
		$frozen1->last_entry = $expenseUpdated;
		$frozen1->save();


    	$driverPays = DB::table('driver_payments')
		->where('driver_id', $request->driver)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$firstDate, $lastDate])
    	->sum('amount');

    	$driverPaysQuery = DB::table('driver_payments')
		->where('driver_id', $request->driver)
    	->whereRaw('amount_date BETWEEN ? AND ?', [$firstDate, $lastDate]);
    	$driverPaysQueryResult = $driverPaysQuery->orderBy('updated_at','desc')->first();

    	$where2 = vsprintf(str_replace('?', "'%s'", $driverPaysQuery->toSql()), $driverPaysQuery->getBindings());    	
		if (!empty($driverPaysQueryResult)) {
			$paymentUpdated = $driverPaysQueryResult->updated_at;			
		} else {
			$paymentUpdated = Carbon::now()->subDays(100);
		}

		$frozen2 = new FrozenModel();
		$frozen2->report_type = 'driver_payment';
		$frozen2->query_searched = $where2;
		$frozen2->last_entry = $paymentUpdated;
		$frozen2->save();

		$driver_salaries = DriverSalary::where('salary_month', $salaryMonthYear)->where('driver_id', $request->driver)->sum('amount');

		$driverQuery =  DriverSalary::where('salary_month', $salaryMonthYear)->where('driver_id', $request->driver);
		$salaryResult = $driverQuery->orderBy('updated_at','desc')->first();
		$where  = vsprintf(str_replace('?', "'%s'", $driverQuery->toSql()), $driverQuery->getBindings());
		if (!empty($salaryResult)) {
			$salaryUpdated = $salaryResult->updated_at;			
		} else {
			$salaryUpdated = Carbon::now()->subDays(100);
		}

		$frozen = new FrozenModel();
		$frozen->report_type = 'driver_salary';
		$frozen->query_searched = $where;
		$frozen->last_entry = $salaryUpdated;
		$frozen->save();

		return back()->withErrors(["error" => "Report Data Freezed!"]);
		
	}

	public function customers() {
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		// data of current month and current year
		$customers = Bookings::select(['id', 'customer_id', 'vehicle_id'])->where('status', 1)->whereIn('vehicle_id', $vehicle_ids)->groupBy('customer_id')->get();
		$customers_by_year = array();
		foreach ($customers as $d) {
			$customers_by_year[$d->customer->name] = Bookings::meta()
				->where(function ($query) {
					$query->where('bookings_meta.key', '=', 'tax_total');

				})->whereYear("bookings.updated_at", date("Y"))->where('customer_id', $d->customer_id)->whereIn('vehicle_id', $vehicle_ids)->sum('value');

		}

		$data['customers_by_year'] = $customers_by_year;
		arsort($customers_by_year);
		$data['top10'] = array_slice($customers_by_year, 0, 10);

		$customers_by_month = array();
		foreach ($customers as $d) {
			$customers_by_month[$d->customer->name] = Bookings::meta()
				->where(function ($query) {
					$query->where('bookings_meta.key', '=', 'tax_total');

				})->whereYear("bookings.updated_at", date("Y"))->whereMonth("bookings.updated_at", date("n"))->where('customer_id', $d->customer_id)->whereIn('vehicle_id', $vehicle_ids)->sum('value');

		}
		$data['customers_by_month'] = $customers_by_month;
		$years = collect(DB::select("select distinct year(created_at) as years from bookings where deleted_at is null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {
			$y[date('Y')] = date('Y');
		}

		$data['year_select'] = date("Y");
		$data['month_select'] = date("n");
		$data['years'] = $y;
		return view('reports.customer', $data);

	}

	public function customers_post(Request $request) {
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		// data of selected month and year
		$customers = Bookings::select(['id', 'customer_id', 'vehicle_id'])->where('status', 1)->whereIn('vehicle_id', $vehicle_ids)->groupBy('customer_id')->get();
		$customers_by_year = array();
		foreach ($customers as $d) {
			$customers_by_year[$d->customer->name] = Bookings::meta()
				->where(function ($query) {
					$query->where('bookings_meta.key', '=', 'tax_total');

				})->whereYear("bookings.updated_at", $request->get("year"))->where('customer_id', $d->customer_id)->whereIn('vehicle_id', $vehicle_ids)->sum('value');

		}
		$data['customers_by_year'] = $customers_by_year;

		arsort($customers_by_year);
		$data['top10'] = array_slice($customers_by_year, 0, 10);
		$customers_by_month = array();
		foreach ($customers as $d) {
			$customers_by_month[$d->customer->name] = Bookings::meta()
				->where(function ($query) {
					$query->where('bookings_meta.key', '=', 'tax_total');

				})->whereYear("bookings.updated_at", $request->get("year"))->whereMonth("bookings.updated_at", $request->get("month"))->where('customer_id', $d->customer_id)->whereIn('vehicle_id', $vehicle_ids)->sum('value');

		}
		$data['customers_by_month'] = $customers_by_month;

		$years = collect(DB::select("select distinct year(created_at) as years from bookings where deleted_at is null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");
		$data['years'] = $y;

		return view('reports.customer', $data);

	}

	public function print_deliquent(Request $request) {
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");
		foreach ($data['vehicles'] as $row) {
			$data['v'][$row['id']] = $row;
		}

		$data['vehicle_id'] = $request->get("vehicle_id");
		$income = IncomeModel::select(['vehicle_id', 'income_cat', 'date', DB::raw('sum(amount) as Income2,dayname(date) as day')])->whereYear('date', $data['year_select'])->whereMonth('date', $data['month_select'])->groupBy('date')->orderBy('date');
		if ($data['vehicle_id'] != "") {
			$data['data'] = $income->where('vehicle_id', $data['vehicle_id'])->get();
		} else {
			$data['data'] = $income->whereIn('vehicle_id', $vehicle_ids)->get();
		}

		$data['vehicle'] = VehicleModel::find($request->get('vehicle_id'));
		return view('reports.print_delinquent', $data);
	}

	public function print_monthly(Request $request) {
		$b = array();
		$i = array();
		$c = array();

		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");
		$data['vehicle_select'] = $request->get("vehicle_id");
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}

		$records = Expense::whereIn('vehicle_id', $vehicle_ids)->whereYear("date", $request->year)->whereMonth("date", $request->month);
		if ($request->vehicle_id != null) {
			$data['expense'] = $records->where('vehicle_id', $request->vehicle_id)->get();
		} else {
			$data['expense'] = $records->get();
		}
		$query = Expense::whereIn('vehicle_id', $vehicle_ids)->whereYear("date", $request->year)->whereMonth("date", $request->month);
		if ($request->vehicle_id != null) {
			$result = $query->where('vehicle_id', $request->vehicle_id)->orderBy('date', 'desc')->first();
		} else {
			 $result = $query->orderBy('date', 'desc')->first();
		}
		if (!empty($result)) {
			$where = vsprintf(str_replace('?', "'%s'", $records->toSql()), $records->getBindings());
			$frozen = new FrozenModel();
			$frozen->report_type = 'monthly_expense';
			$frozen->query_searched = $where;
			$frozen->last_entry = $result->updated_at;
			$frozen->save();
			return back()->withErrors(["error" => "Report Data Freezed!"]);
		} else {
			return back()->withErrors(["error" => "No data available to freeze!"]);
		}		


	}

	public function print_booking(Request $request) {
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$data['customers'] = User::where('user_type', 'C')->get();
		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");
		$data['bookings'] = Bookings::whereMonth("pickup", $data['month_select'])->whereMonth("pickup", $data['month_select'])->whereIn('vehicle_id', $vehicle_ids);
		if ($request->get("vehicle_id") != "") {
			$data['bookings'] = $data['bookings']->where("vehicle_id", $request->get("vehicle_id"));
		}
		if ($request->get("customer_id") != "") {
			$data['bookings'] = $data['bookings']->where("customer_id", $request->get("customer_id"));
		}
		$data['bookings'] = $data['bookings']->get();
		return view('reports.print_bookings', $data);
	}

	

	

	

	public function print_vendor() {
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$data['details'] = WorkOrders::select(['vendor_id', DB::raw('sum(price) as total')])->whereIn('vehicle_id', $vehicle_ids)->groupBy('vendor_id')->get();

		$kk = WorkOrders::select('vendor_id')->whereIn('vehicle_id', $vehicle_ids)->groupBy('vendor_id')->get();
		$b = array();
		foreach ($kk as $k) {
			$b[$k->vendor_id] = $k->vendor->name;

		}
		$data['vendors'] = $b;

		return view('reports.print_vendor', $data);
	}

	public function print_customer(Request $request) {
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$customers = Bookings::select(['id', 'customer_id', 'vehicle_id'])->where('status', 1)->whereIn('vehicle_id', $vehicle_ids)->groupBy('customer_id')->get();
		$customers_by_year = array();
		foreach ($customers as $d) {
			$customers_by_year[$d->customer->name] = Bookings::meta()
				->where(function ($query) {
					$query->where('bookings_meta.key', '=', 'tax_total');

				})->whereYear("bookings.updated_at", $request->get("year"))->where('customer_id', $d->customer_id)->whereIn('vehicle_id', $vehicle_ids)->sum('value');

		}
		$data['customers_by_year'] = $customers_by_year;

		arsort($customers_by_year);
		$data['top10'] = array_slice($customers_by_year, 0, 10);

		$customers_by_month = array();
		foreach ($customers as $d) {
			$customers_by_month[$d->customer->name] = Bookings::meta()
				->where(function ($query) {
					$query->where('bookings_meta.key', '=', 'tax_total');

				})->whereYear("bookings.updated_at", $request->get("year"))->whereMonth("bookings.updated_at", $request->get("month"))->where('customer_id', $d->customer_id)->whereIn('vehicle_id', $vehicle_ids)->sum('value');

		}

		$data['customers_by_month'] = $customers_by_month;

		$years = collect(DB::select("select distinct year(created_at) as years from bookings where deleted_at is null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");
		$data['years'] = $y;
		return view('reports.print_customer', $data);
	}

	public function users() {
		$years = collect(DB::select("select distinct year(pickup) as years from bookings where deleted_at is null and pickup is not null order by years desc"))->toArray();

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		$data['users'] = User::where('user_type', 'O')->orWhere('user_type', 'S')->get();
		$data['user_id'] = "";
		$data['year_select'] = date("Y");
		$data['month_select'] = date("n");
		$data['years'] = $y;
		return view('reports.users', $data);
	}

	public function users_post(Request $request) {
		$years = DB::select("select distinct year(pickup) as years from bookings where deleted_at is null and pickup is not null order by years desc");
		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}
		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		$data['users'] = User::where('user_type', 'O')->orWhere('user_type', 'S')->get();
		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");

		$data['user_id'] = $request->get("user_id");
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}

		$data['data'] = Bookings::whereYear('pickup', $data['year_select'])->whereMonth('pickup', $data['month_select'])->where('user_id', $request->get('user_id'))->whereIn('vehicle_id', $vehicle_ids)->get();

		$data['years'] = $y;
		$data['result'] = "";

		return view("reports.users", $data);
	}

	public function print_users(Request $request) {

		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");
		
		$data['vehicles'] = VehicleModel::when(Auth::user()->group_id == null || Auth::user()->user_type == "S", function ($query) {
			// Apply this query when the condition is true (role is false or null)
			return $query->get();
		}, function ($query) {
			// Apply this query when the condition is false (role is provided)
			return $query->where('group_id', Auth::user()->group_id)->get();
		});

		$vehicle_ids = array(0);
		foreach ($data['vehicles'] as $vehicle) {
			$vehicle_ids[] = $vehicle->id;
		}
		$data['data'] = Bookings::whereYear('pickup', $data['year_select'])->whereMonth('pickup', $data['month_select'])->where('user_id', $request->get('user_id'))->whereIn('vehicle_id', $vehicle_ids)->get();

		return view('reports.print_users', $data);
	}

	public function work_order() {
		$years = DB::select("select distinct year(required_by) as years from work_orders where deleted_at is null and required_by is not null order by years desc");

		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}

		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		$data['vehicle'] = VehicleModel::all();
		$data['vehicle_id'] = "";
		$data['year_select'] = date("Y");
		$data['month_select'] = date("n");
		$data['years'] = $y;
		return view('reports.work_order', $data);
	}

	public function work_order_post(Request $request) {
		$years = DB::select("select distinct year(required_by) as years from work_orders where deleted_at is null and required_by is not null order by years desc");
		$y = array();
		foreach ($years as $year) {
			$y[$year->years] = $year->years;
		}
		if ($years == null) {
			$y[date('Y')] = date('Y');
		}
		$data['vehicle'] = VehicleModel::all();
		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");

		$data['vehicle_id'] = $request->get("vehicle_id");

		$data['data'] = WorkOrders::whereYear('required_by', $data['year_select'])->whereMonth('required_by', $data['month_select'])->where('vehicle_id', $request->get('vehicle_id'))->get();

		$data['years'] = $y;
		$data['result'] = "";

		return view("reports.work_order", $data);
	}

	public function print_workOrder_report(Request $request) {
		$data['year_select'] = $request->get("year");
		$data['month_select'] = $request->get("month");

		$data['data'] = WorkOrders::whereYear('required_by', $data['year_select'])->whereMonth('required_by', $data['month_select'])->where('vehicle_id', $request->get('vehicle_id'))->get();
		return view("reports.print_work_order", $data);
	}
}
