<?php

/*
@copyright

Fleet Manager v6.5

Copyright (C) 2017-2023 Hyvikk Solutions <https://hyvikk.com/> All rights reserved.
Design and developed by Hyvikk Solutions <https://hyvikk.com/>

 */

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\VehicleMovementRequest;
use App\Model\VehicleMovementModel;
use App\Http\Requests\ImportRequest;
use App\Model\VehicleModel;
use DataTables;
use Auth;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;
use App\Imports\MovementsImport;

class VehicleMovementController extends Controller {

	public function __construct() {
	}
	public function index() {
		
		// if (Auth::user()->user_type == "S" || Auth::user()->user_type != "D") {
		// 	if (Auth::user()->group_id == null) {
		// 		$vehicle_ids = VehicleModel::pluck('id')->toArray();
		// 	} else {
		// 		$vehicle_ids = VehicleModel::where('group_id', Auth::user()->group_id)->pluck('id')->toArray();
		// 	}
		// }
		$vehicle_ids = VehicleModel::pluck('id')->toArray();
		
		$data['data'] = VehicleMovementModel::orderBy('id', 'desc')->whereIn('vehicle_id', $vehicle_ids)->get();
		
		return view('vehicle_movements.index', $data);
	}
	public function create() {
		$data['vehicles'] =VehicleModel::whereIn_service("1")->get();
		$data['sources'] = VehicleMovementModel::groupBy('source')->get()->pluck('source')->toArray();
		$data['payment_sources'] = VehicleMovementModel::groupBy('payment_source')->get()->pluck('payment_source')->toArray();
		$data['destinations'] = VehicleMovementModel::groupBy('destination')->get()->pluck('destination')->toArray();
		$data['parties'] = VehicleMovementModel::groupBy('party')->get()->pluck('party')->toArray();
		return view('vehicle_movements.create', $data);
	}

	private function upload_file($file, $field, $id) {
		$destinationPath = './uploads'; // upload path
		$extension = $file->getClientOriginalExtension();
		$fileName1 = Str::uuid() . '.' . $extension;

		$file->move($destinationPath, $fileName1);

		$x = VehicleMovementModel::find($id)->update([$field => $fileName1]);

	}

	public function store(VehicleMovementRequest $request) {
		// dd($request->all());
		


		$movement = new VehicleMovementModel();
		$movement->user_id = Auth::user()->id;
		$movement->vehicle_id = $request->get('vehicle_id');
		$movement->source = $request->get('source');
		$movement->destination = $request->get('destination');
		$movement->party = $request->get('party');
		$movement->loading = $request->get('loading');
		$movement->freight = $request->get('freight');
		$movement->advance = $request->get('advance');
		$movement->commission = $request->get('commission');
		$movement->balance = $request->get('balance');
		$movement->doc_no = $request->get('doc_no');
		$movement->payment_source = $request->get('payment_source');

		$movement->save();
		$id = $movement->id;
		if ($request->file('pod_upload')) {
			$this->upload_file($request->file('pod_upload'), "pod_upload", $id);

		}
		return redirect('admin/vehicle-movement');
	}

	public function edit($id) {
		$data['data'] = $data = VehicleMovementModel::whereId($id)->get()->first();
		$data['vehicles'] =VehicleModel::whereIn_service("1")->get();
		$data['vehicle_id'] = $data->vehicle_id;
		$data['sources'] = VehicleMovementModel::groupBy('source')->get()->pluck('source')->toArray();
		$data['destinations'] = VehicleMovementModel::groupBy('destination')->get()->pluck('destination')->toArray();
		$data['payment_sources'] = VehicleMovementModel::groupBy('payment_source')->get()->pluck('payment_source')->toArray();
		$data['parties'] = VehicleMovementModel::groupBy('party')->get()->pluck('party')->toArray();
		return view('vehicle_movements.edit', $data);

	}

	public function update(VehicleMovementRequest $request) {
		// dd($request->all());
		$movement = VehicleMovementModel::find($request->get("id"));
		// $form_data = $request->all();
		
		$movement->vehicle_id = $request->get('vehicle_id');
		$movement->source = $request->get('source');
		$movement->destination = $request->get('destination');
		$movement->party = $request->get('party');
		$movement->loading = $request->get('loading');
		$movement->freight = $request->get('freight');
		$movement->advance = $request->get('advance');
		$movement->commission = $request->get('commission');
		$movement->balance = $request->get('balance');
		$movement->doc_no = $request->get('doc_no');
		$movement->payment_source = $request->get('payment_source');

		$movement->save();
		$id = $movement->id;
		if ($request->file('pod_upload')) {
			$this->upload_file($request->file('pod_upload'), "pod_upload", $id);

		}
		
		return redirect('admin/vehicle-movement');

	}

	public function destroy(Request $request) {
		$movement = VehicleMovementModel::find($request->get('id'));

		

		$movement->delete();
		return redirect('admin/vehicle-movement');
	}

	public function bulk_delete(Request $request) {
		$movements = VehicleMovementModel::whereIn('id', $request->ids)->get();
		foreach ($movements as $movement) {
			
			$movement->delete();
		}
		
		return redirect()->back();
	}

	public function importMovements(ImportRequest $request) {
		$file = $request->excel;
		$destinationPath = './assets/samples/'; // upload path
		$extension = $file->getClientOriginalExtension();
		$fileName = Str::uuid() . '.' . $extension;
		$file->move($destinationPath, $fileName);

		Excel::import(new MovementsImport, 'assets/samples/' . $fileName);
		return redirect('admin/vehicle-movement');
	}

	
}
