<?php

/*
@copyright

Fleet Manager v6.5

Copyright (C) 2017-2023 Hyvikk Solutions <https://hyvikk.com/> All rights reserved.
Design and developed by Hyvikk Solutions <https://hyvikk.com/>

*/

namespace App\Imports;

use App\Model\FuelModel;
use Maatwebsite\Excel\Concerns\ToModel;
use Spatie\Permission\Models\Permission;
use App\Model\VehicleModel;
use App\Model\Vendor;
use Maatwebsite\Excel\Concerns\WithHeadingRow;
use Illuminate\Validation\Rule;
use Carbon\Carbon;
use App\Model\Expense;
use Illuminate\Support\Facades\Auth;

class FuelImport implements ToModel, WithHeadingRow
{
    /**
    * @param array $row
    *
    * @return \Illuminate\Database\Eloquent\Model|null
    */
    public function model(array $fuel)
    {
        $vehicle_id = VehicleModel::where('license_plate', $fuel['number_plate'])->value('id');
        if (!empty($vehicle_id)) {
            $filling = trim($fuel['filling_station']);
            $vendor_id = '';
            if (!empty($filling)) {
                 $vendor_id = Vendor::where('name', $filling)->value('id');
                 if (empty($vendor_id)) {
                    $vendor_id = Vendor::create([
                        "user_id" => "1",
                        "name" => $filling,
                        "type" => 'fuel',
                    ])->id;                
                }
            }
           
            

            if(!empty($fuel['cost_per_unit']) && !empty($fuel['total_price'])) {
                $convertedDate = '';
                if (!empty($fuel['date'])) {
                    $convertedDate = $this->convertExcelDate($fuel['date']);
                }

                 $totalPrice =  sprintf('%.2f', $fuel['total_price']);
                 $ttlQty = $fuel['total_price']/$fuel['cost_per_unit'];                 
                    $id = FuelModel::create([
                       "start_meter" => "0",
                        "user_id" => Auth::user()->id,
                        "end_meter" => "0",
                        "consumption" => "0",
                        "cost_per_unit" => $fuel['cost_per_unit'],
                        'vendor_name' => ($vendor_id) ? $vendor_id : '',
                        'vehicle_id' => $vehicle_id,
                        'fuel_from' => 'Vendor',
                        'qty' => floor($ttlQty * 100) / 100,
                        'date' => $convertedDate,
                    ])->id;

                    $fuleModel = FuelModel::find($id);
                    $fuleModel->fuel_cost = $totalPrice;
                    $fuleModel->save();

                    
            }
        }
        
    }

    private function convertExcelDate($excelDate)
    {
        // Excel date starts from 1900-01-01
        return Carbon::createFromFormat('Y-m-d', '1900-01-01')->addDays($excelDate - 2)->format('Y-m-d');
    }

    
}
