@extends('layouts.app')
@section('extra_css')
<style type="text/css">
  /* The switch - the box around the slider */
  .switch {
    position: relative;
    display: inline-block;
    width: 60px;
    height: 34px;
  }

  /* Hide default HTML checkbox */
  .switch input {
    display: none;
  }

  /* The slider */
  .slider {
    position: absolute;
    cursor: pointer;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background-color: #ccc;
    -webkit-transition: .4s;
    transition: .4s;
  }

  .slider:before {
    position: absolute;
    content: "";
    height: 26px;
    width: 26px;
    left: 4px;
    bottom: 4px;
    background-color: white;
    -webkit-transition: .4s;
    transition: .4s;
  }

  input:checked+.slider {
    background-color: #2196F3;
  }

  input:focus+.slider {
    box-shadow: 0 0 1px #2196F3;
  }

  input:checked+.slider:before {
    -webkit-transform: translateX(26px);
    -ms-transform: translateX(26px);
    transform: translateX(26px);
  }

  /* Rounded sliders */
  .slider.round {
    border-radius: 34px;
  }

  .slider.round:before {
    border-radius: 50%;
  }
</style>
<link rel="stylesheet" href="{{asset('assets/css/bootstrap-datepicker.min.css')}}">
@endsection
@section("breadcrumb")
<li class="breadcrumb-item">{{ link_to_route('vehicle_movement', __('Vehicle Movement'))}}</li>
<li class="breadcrumb-item active">Edit Vehicle Movement</li>
@endsection
@section('content')
<div class="row">
  <div class="col-md-12">
    <div class="card card-success">
      <div class="card-header">
        <h3 class="card-title">Edit Vehicle Movement</h3>
      </div>

      <div class="card-body">
        @if (count($errors) > 0)
          <div class="alert alert-danger">
            <ul>
              @foreach ($errors->all() as $error)
              <li>{{ $error }}</li>
              @endforeach
            </ul>
          </div>
        @endif

      {!! Form::open(['route' => ['vehicle_movement.update',$data->id],'method'=>'post','files'=>'true']) !!}
      {!! Form::hidden('id',$data->id)!!}
      <div class="row">
       <div class="form-group col-md-6">
              {!! Form::label('vehicle_id',__('fleet.selectVehicle'), ['class' => 'form-label']) !!}
              <select id="vehicle_id" name="vehicle_id" class="form-control" required>
                <option value=""></option>
                @foreach($vehicles as $vehicle)
                <option @if($vehicle->id == $data->vehicle_id) selected @endif value="{{$vehicle->id}}">{{$vehicle->make_name}} - {{$vehicle->model_name}} -
                  {{$vehicle->license_plate}}</option>
                @endforeach
              </select>
            </div>

            <div class="form-group col-md-6">
                  <label for="color_name" class="col-xs-5 control-label">Select Vehicle Source</label>
                  <a data-toggle="modal" data-target="#myModal3"><i class="fa fa-info-circle fa-lg" aria-hidden="true" style="color: #8639dd"></i></a>

                  <div class="col-xs-6">
                   <select name="source" class="form-control" required id="source">
                    <option></option>
                    @foreach ($sources as $source)   
                    <option value="{{$source}}" @if($source == $data->source) selected @endif>{{$source}}</option>
                    @endforeach
                  </select>
                  </div>
                </div>

                <div class="form-group col-md-6">
                  <label for="destination" class="col-xs-5 control-label">Select Vehicle Destination</label>
                  <a data-toggle="modal" data-target="#myModal2"><i class="fa fa-info-circle fa-lg" aria-hidden="true" style="color: #8639dd"></i></a>

                  <div class="col-xs-6">
                   <select name="destination" class="form-control" required id="destination">
                    <option></option>
                    @foreach ($destinations as $destination)   
                    <option value="{{$destination}}" @if($destination == $data->destination) selected @endif>{{$destination}}</option>
                    @endforeach
                  </select>
                  </div>
                </div>

                <div class="form-group col-md-6">
                  <label for="party" class="col-xs-5 control-label">Select Vehicle Party</label>
                  <a data-toggle="modal" data-target="#myModal1"><i class="fa fa-info-circle fa-lg" aria-hidden="true" style="color: #8639dd"></i></a>

                  <div class="col-xs-6">
                   <select name="party" class="form-control" required id="party">
                    <option></option>
                    @foreach ($parties as $party)   
                    <option value="{{$party}}" @if($party == $data->party) selected @endif>{{$party}}</option>
                    @endforeach
                  </select>
                  </div>
                </div>
                <div class="form-group col-md-6">
              {!! Form::label('loading','Loading', ['class' => 'form-label']) !!}
              <div class='input-group'>
                <div class="input-group-prepend">
                  <span class="input-group-text"><span class="fa fa-calendar"></span>
                  </span>
                </div>
                {!! Form::text('loading',$data->loading,['class'=>'form-control','required']) !!}
              </div>
            </div>
            <div class="col-md-6 form-group">
                  {!! Form::label('pod_upload', __('POD Attachment'), ['class' => 'col-xs-5 control-label']) !!}
                  <div class="col-xs-6">
                    {!! Form::file('pod_upload',null,['class' => 'form-control']) !!}
                    @if (!is_null($data->pod_upload) && file_exists('uploads/'.$data->pod_upload))
                        <a href="{{ url('uploads/'.$data->pod_upload) }}" target="_blank">View</a>
                    @endif
                  </div>
                </div>
            <div class="form-group col-md-6">
                  <label for="freight" class="form-label">Freight</label>
                  <div class="input-group mb-3">
                    <div class="input-group-prepend">
                      <span class="input-group-text">₹</span>
                    </div>
                    <input class="form-control" step="0.01" min="10" name="freight" type="number" id="freight" required value="{{ $data->freight }}">
                  </div>
                </div>
                <div class="form-group col-md-6">
                  <label for="advance" class="form-label">Advance</label>
                  <div class="input-group mb-3">
                    <div class="input-group-prepend">
                      <span class="input-group-text">₹</span>
                    </div>
                    <input class="form-control" step="0.01" min="10" name="advance" type="number" value="{{ $data->advance }}" id="advance" required>
                  </div>
                </div>
                <div class="form-group col-md-6">
                  <label for="commission" class="form-label">Commission</label>
                  <div class="input-group mb-3">
                    <div class="input-group-prepend">
                      <span class="input-group-text">₹</span>
                    </div>
                    <input class="form-control" step="0.01" min="10" name="commission" type="number" value="{{ $data->commission }}" id="commission" required>
                  </div>
                </div>
                <div class="form-group col-md-6">
                  <label for="balance" class="form-label">Balance</label>
                  <div class="input-group mb-3">
                    <div class="input-group-prepend">
                      <span class="input-group-text">₹</span>
                    </div>
                    <input class="form-control" step="0.01" min="10" name="balance" type="number" value="{{ $data->balance }}" id="balance" required style="pointer-events:none;">
                  </div>
                </div>
                <div class="form-group col-md-6">
                  <label for="doc_no" class="form-label">Doc No.</label>
                  <div class="input-group mb-3">
                    <input class="form-control" name="doc_no" value="{{ $data->doc_no }}" type="text"  id="doc_no" required>
                  </div>
                </div>
            <div class="form-group col-md-6">
                  <label for="color_name" class="col-xs-5 control-label">Source of Payment</label>
                  <a data-toggle="modal" data-target="#myModal3"><i class="fa fa-info-circle fa-lg" aria-hidden="true" style="color: #8639dd"></i></a>

                  <div class="col-xs-6">
                   <select name="payment_source" class="form-control" required id="payment_source">
                    <option></option>
                    @foreach ($payment_sources as $payment_source)   
                    <option value="{{$payment_source}}" @if($payment_source == $data->payment_source) selected @endif>{{$payment_source}}</option>
                    @endforeach
                    
                  </select>
                  </div>
                </div>
             <div class="form-group col-md-12 mt-3">
            {!! Form::submit(__('fleet.save'), ['class' => 'btn btn-success']) !!}
          </div>

      </div>
      </div>
      
      {!! Form::close() !!}
    </div>
  </div>
</div>

<div id="myModal3" class="modal fade" role="dialog">
  <div class="modal-dialog" role="document">
    <!-- Modal content-->
    <div class="modal-content">
      <div class="modal-header">
        <h4 class="modal-title">Add New Source</h4>
        <button type="button" class="close" data-dismiss="modal">&times;</button>
      </div>
      <div class="modal-body">
        <p>You can create a new source by typing it in the textbox and selecting the entered source.</p>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-default" data-dismiss="modal">@lang('fleet.close')</button>
      </div>
    </div>
  </div>
</div>

<div id="myModal2" class="modal fade" role="dialog">
  <div class="modal-dialog" role="document">
    <!-- Modal content-->
    <div class="modal-content">
      <div class="modal-header">
        <h4 class="modal-title">Add New Destination</h4>
        <button type="button" class="close" data-dismiss="modal">&times;</button>
      </div>
      <div class="modal-body">
        <p>You can create a new destination by typing it in the textbox and selecting the entered destination.</p>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-default" data-dismiss="modal">@lang('fleet.close')</button>
      </div>
    </div>
  </div>
</div>

<div id="myModal1" class="modal fade" role="dialog">
  <div class="modal-dialog" role="document">
    <!-- Modal content-->
    <div class="modal-content">
      <div class="modal-header">
        <h4 class="modal-title">Add New Party</h4>
        <button type="button" class="close" data-dismiss="modal">&times;</button>
      </div>
      <div class="modal-body">
        <p>You can create a new party by typing it in the textbox and selecting the entered party.</p>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-default" data-dismiss="modal">@lang('fleet.close')</button>
      </div>
    </div>
  </div>
</div>
@endsection
@section('script')
<script type="text/javascript">
  $(document).ready(function() {
  //Flat green color scheme for iCheck
    $('input[type="checkbox"].flat-red, input[type="radio"].flat-red').iCheck({
      checkboxClass: 'icheckbox_flat-green',
      radioClass   : 'iradio_flat-green'
    });
  });
  $('#source').select2({placeholder:"Select Vehicle Source",tags:true});
  $('#destination').select2({placeholder:"Select Vehicle Destination",tags:true});
  $('#party').select2({placeholder:"Select Vehicle Party",tags:true});
  $('#payment_source').select2({placeholder:"Select Payment Source",tags:true});
  var oneMonthAgo = new Date();
  oneMonthAgo.setMonth(oneMonthAgo.getMonth() - 1);
  $('#loading').datepicker({
    autoclose: true,
    format: 'yyyy-mm-dd',
    startDate: oneMonthAgo,
    endDate: null, // Allow all future dates
  });
    $('#freight, #advance, #commission').on('keydown keyup', function(event) {
  getBalance();
});

  function getBalance() {
    var freight = $('#freight').val();    
    var advance = $('#advance').val();
    if (advance.length > 0) {
      freight = freight - advance;
    }
    var commission = $('#commission').val();
    if (commission.length > 0) {
      freight = freight - commission;
    }
    $('#balance').val(freight);

  }
</script>
@endsection